==> flowbase-0.0.1.tar.gz: flowbase-0.0.1/README.md <==
# FlowBase-Python

Python implementation of the [FlowBase micro-FBP framework
idea](https://flowbase.org), using Python's asyncio library, introduced in
Python 3.4/3.5.

## Installation

```bash
git clone git@github.com:flowbase/flowbase-python.git
cd flowbase-python
pip install .
```

## Try an example

```
cd examples
python string_processing_pipeline.py
```

### Expected output:

```bash
$ python string_processing_pipeline.py
Printer got line: hi hi for the 1:TH TIME...
Printer got line: hi hi for the 2:TH TIME...
Printer got line: hi hi for the 3:TH TIME...
Printer got line: hi hi for the 4:TH TIME...
Printer got line: hi hi for the 5:TH TIME...
Printer got line: hi hi for the 6:TH TIME...
Printer got line: hi hi for the 7:TH TIME...
Printer got line: hi hi for the 8:TH TIME...
Printer got line: hi hi for the 9:TH TIME...
Printer got line: hi hi for the 10:TH TIME...
Printer got line: hi hi for the 11:TH TIME...
Printer got line: hi hi for the 12:TH TIME...
Printer got line: hi hi for the 13:TH TIME...
Printer got line: hi hi for the 14:TH TIME...
Printer got line: hi hi for the 15:TH TIME...
Printer got line: hi hi for the 16:TH TIME...
Printer got line: hi hi for the 17:TH TIME...
Printer got line: hi hi for the 18:TH TIME...
Printer got line: hi hi for the 19:TH TIME...
Printer got line: hi hi for the 20:TH TIME...
```

## Acknowledgements

Kudos to [Simone Baffelli](https://github.com/baffelli)'s
[Pyperator](https://github.com/baffelli/pyperator/) library which showed that
it is in fact possible to implement an FBP-like library using asyncio.

==> flowbase-0.0.3.tar.gz: flowbase-0.0.3/README.md <==
# FlowBase-Python

Python implementation of the [FlowBase micro-FBP framework
idea](https://flowbase.org), using Python's asyncio library, introduced in
Python 3.4/3.5.

## Installation

```bash
pip install flowbase
```

## Try an example

```
cd examples
python string_processing_pipeline.py
```

### Expected output:

```bash
$ python string_processing_pipeline.py
Printer got line: hi hi for the 1:TH TIME...
Printer got line: hi hi for the 2:TH TIME...
Printer got line: hi hi for the 3:TH TIME...
Printer got line: hi hi for the 4:TH TIME...
Printer got line: hi hi for the 5:TH TIME...
Printer got line: hi hi for the 6:TH TIME...
Printer got line: hi hi for the 7:TH TIME...
Printer got line: hi hi for the 8:TH TIME...
Printer got line: hi hi for the 9:TH TIME...
Printer got line: hi hi for the 10:TH TIME...
Printer got line: hi hi for the 11:TH TIME...
Printer got line: hi hi for the 12:TH TIME...
Printer got line: hi hi for the 13:TH TIME...
Printer got line: hi hi for the 14:TH TIME...
Printer got line: hi hi for the 15:TH TIME...
Printer got line: hi hi for the 16:TH TIME...
Printer got line: hi hi for the 17:TH TIME...
Printer got line: hi hi for the 18:TH TIME...
Printer got line: hi hi for the 19:TH TIME...
Printer got line: hi hi for the 20:TH TIME...
```

## Acknowledgements

Kudos to [Simone Baffelli](https://github.com/baffelli)'s
[Pyperator](https://github.com/baffelli/pyperator/) library which showed that
it is in fact possible to implement an FBP-like library using asyncio.
